@@ -62,18 +62,27 @@ class Statement:
         self.style = style
 
     def evaluate(self, scope: dict) -> Result:
+        if "__name__" not in scope:
+            scope["__name__"] = "__reprex__"
         stdout_io = StringIO()
         try:
             with redirect_stdout(stdout_io):
                 try:
-                    result = eval(str(self).strip(), scope, scope)
+                    result = eval(str(self).strip(), scope)
                 except SyntaxError:
-                    exec(str(self).strip(), scope, scope)
+                    exec(str(self).strip(), scope)
                     result = NO_RETURN
             stdout = stdout_io.getvalue().strip()
-        except Exception:
+        except Exception as exc:
             result = NO_RETURN
-            stdout = traceback.format_exc().strip()
+            # Skip first step of traceback, since that is this evaluate method
+            if exc.__traceback__ is not None:
+                tb = exc.__traceback__.tb_next
+                stdout = (
+                    "Traceback (most recent call last):\n"
+                    + "".join(line for line in traceback.format_tb(tb))
+                    + f"{type(exc).__name__}: {exc}"
+                )
         finally:
             stdout_io.close()
         return Result(result, stdout=stdout)
@@ -131,6 +140,8 @@ class CodeBlock:
                 match the `comment` prefix. False means these lines are removed, in effect meaning
                 an inputted regex will have its results regenerated. Defaults to False.
         """
+        if any(line.startswith(">>>") for line in input.split("\n")):
+            input = repl_to_reprex_code(input, comment=comment)
         if not old_results and comment in input:
             input = "\n".join(line for line in input.split("\n") if not line.startswith(comment))
         self.input: str = input
@@ -177,3 +188,24 @@ class CodeBlock:
         except ImportError:
             out.append(f"<pre><code>{self}</code></pre>")
         return "\n".join(out)
+
+
+def repl_to_reprex_code(input: str, comment: str = "#>") -> str:
+    """Reformat a code block copied from a Python REPL to a reprex-style code block.
+
+    Args:
+        input (str): code block
+        comment (str): Line prefix to use when rendering the evaluated results. Defaults to "#>".
+
+    Returns:
+        Reformatted code block in reprex-style.
+    """
+    out = []
+    for line in input.split("\n"):
+        if line.startswith(">>>") or line.startswith("..."):
+            out.append(line[4:])
+        elif line.strip() == "":
+            out.append(line)
+        else:
+            out.append(comment + " " + line)
+    return "\n".join(out)
